@@ -1,16 +1,16 @@
 from typing import Any
 from navalmartin_mir_db_utils.dbs.dbs_utils import DB_ERROR
 from navalmartin_mir_db_utils.dbs.mongodb_session import MongoDBSession
-from navalmartin_mir_db_utils.utils.exceptions import (ResourceNotFoundException, ResourceNotUpdatedException)
+from navalmartin_mir_db_utils.utils.exceptions import (ResourceNotFoundException, ResourceNotUpdatedException, ResourceExistsException)
+
 
 async def get_one_result_or_raise(
-    crud_handler,
-    criteria: dict,
-    db_session: MongoDBSession,
-    projection: dict = {},
-    error_message: str = "Error occurred"
+        crud_handler,
+        criteria: dict,
+        db_session: MongoDBSession,
+        projection: dict = {},
+        error_message: str = "Error occurred"
 ):
-
     """Query the handler about a result and raise
     ResourceNotFoundException if the query does not return any
     result
@@ -25,12 +25,27 @@ async def get_one_result_or_raise(
 
     return result
 
+
+async def if_resource_found_raise(crud_handler,
+                                  criteria: dict,
+                                  db_session: MongoDBSession,
+                                  error_message: str = "Error occurred"):
+
+    result = await crud_handler.find_one(
+        criteria=criteria, db_session=db_session, projection={'_id': True}
+    )
+
+    if result is not None:
+        print(f"{DB_ERROR} {error_message}")
+        raise ResourceExistsException(resource_id=str(criteria))
+
+
 async def update_one_or_raise(
-    crud_handler: Any,
-    criteria: dict,
-    db_session,
-    update_data: dict,
-    error_message: str = "Error occurred",
+        crud_handler: Any,
+        criteria: dict,
+        db_session,
+        update_data: dict,
+        error_message: str = "Error occurred",
 ):
     result = await crud_handler.update_one(
         criteria=criteria, db_session=db_session, update_data=update_data
@@ -40,8 +55,8 @@ async def update_one_or_raise(
         print(f"{DB_ERROR} {error_message}")
         raise ResourceNotUpdatedException(resource_id=str(criteria))
 
-    if result.modified_count != 1 :
+    if result.modified_count != 1:
         print(f"{DB_ERROR} {error_message}")
         raise ResourceNotUpdatedException(resource_id=str(criteria))
 
-    return result
\ No newline at end of file
+    return result
