@@ -7,15 +7,25 @@ class InvalidObjectIdException(Exception):
 
 
 class ResourceNotFoundException(Exception):
-    def __init__(self, resource_id: str) :
-        self.message =  f"Resource with id {resource_id} not found"
+    def __init__(self, resource_id: str):
+        self.message = f"Resource with id {resource_id} not found"
 
     def __str__(self) -> str:
         return self.message
 
+
 class ResourceNotUpdatedException(Exception):
-    def __init__(self, resource_id: str) :
-        self.message =  f"Resource with id {resource_id} not updated"
+    def __init__(self, resource_id: str):
+        self.message = f"Resource with id {resource_id} not updated"
 
     def __str__(self) -> str:
         return self.message
+
+
+class ResourceExistsException(Exception):
+    def __init__(self, resource_id: str):
+        self.message = f"Resource with id {resource_id} exists"
+
+    def __str__(self) -> str:
+        return self.message
+
